@@ -1,3 +1,5 @@
+from typing import Optional
+
 from .. import Provider as AddressProvider
 
 
@@ -2508,16 +2510,16 @@ class Provider(AddressProvider):
         "Syddanmark",
     )
 
-    def dk_street_name(self) -> str:
+    def dk_street_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
         """
         This returns the name of a street, without any suffix.
         """
-        return self.random_element(self.street_names)
+        return self.random_element(self.street_names, min_length, max_length)
 
-    def city_name(self) -> str:
-        return self.random_element(self.cities)
+    def city_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
+        return self.random_element(self.cities, min_length, max_length)
 
-    def administrative_unit(self) -> str:
-        return self.random_element(self.states)
+    def administrative_unit(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
+        return self.random_element(self.states, min_length, max_length)
 
     state = administrative_unit
